API Documentation
=================

.. automodapi:: spectral_cube
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: spectral_cube.ytcube
   :no-inheritance-diagram:
   :no-inherited-members:

.. automodapi:: spectral_cube.io.casa_masks
   :no-inheritance-diagram:
   :no-inherited-members:

.. automodapi:: spectral_cube.lower_dimensional_structures
   :no-inheritance-diagram:
   :no-inherited-members:

.. automodapi:: spectral_cube.base_class
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: spectral_cube.spectral_cube
   :no-inheritance-diagram:
   :inherited-members:

.. automodapi:: spectral_cube.masks
   :no-inheritance-diagram:
   :inherited-members:

